==> rabbitmq-2024.2.126+6b985e51b.tgz: rabbitmq/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 changes rmq-exporter secret src
- 0.1.4 Add configurable RABBIT_TIMEOUT parameter
- 0.1.5 Update Rabbitmq exporter version
- 0.1.6 Disallow privilege escalation in rabbitmq server container
- 0.1.7 Adding TLS logic to rabbitmq
- 0.1.8 Make helm test work with TLS
- 0.1.9 Use full image ref for docker official images
- 0.1.10 Set separate for HTTPS
- 0.1.11 Add TLS support for helm test
- 0.1.12 Added helm hook post-install and post-upgrade for rabbitmq wait cluster job
- 0.1.13 Add prestop action and version 3.8.x upgrade prep
- 0.1.14 Update readiness and liveness probes
- 0.1.15 Update htk requirements
- 0.1.16 Add force_boot command to rabbit start template
- 0.1.17 Updated naming for subchart compatibility
- 0.1.18 Revert naming for subchart compatibility
- 0.1.19 Enable taint toleration for Openstack services jobs
- 0.1.20 Bump Rabbitmq version to 3.9.0
- 0.1.21 Updated naming for subchart compatibility
- 0.1.22 Remove guest admin account
- 0.1.23 Fixed guest account removal
- 0.1.24 Added OCI registry authentication
- 0.1.25 Add hostPort support
- 0.1.26 Moved guest admin removal to init template
- 0.1.27 Replace node-role.kubernetes.io/master with control-plane
- 0.1.28 Add IPv6 environment support for rabbitmq
- 0.1.29 Add build-in prometheus plugin and disable external exporter
- 0.1.30 Add labels to rabbitmq service
- 0.1.31 Support management api metrics collection
- 0.1.32 Enable addition of default consumer prefetch count
- 0.1.33 Bump RabbitMQ image version to 3.13.0
- 0.1.34 Add 2024.1 overrides
- 0.1.35 Add configurable probes to rabbitmq container
- 0.1.36 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.37 Update rabbitmq readiness/liveness command
- 0.1.38 Do not use hardcoded username in rabbitmq chown container
- 0.1.39 Allow to bootstrap rabbitmq with initial config
- 0.1.40 Set password for guest user rabbitmq
- 0.1.41 Use short rabbitmq node name
- 0.1.42 Revert Use short rabbitmq node name
- 0.1.43 Add 2024.2 overrides
- 0.1.44 Allow to use default storage class
- 0.1.45 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> rabbitmq-2025.1.0+35052e51b.tgz: rabbitmq/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 changes rmq-exporter secret src
- 0.1.4 Add configurable RABBIT_TIMEOUT parameter
- 0.1.5 Update Rabbitmq exporter version
- 0.1.6 Disallow privilege escalation in rabbitmq server container
- 0.1.7 Adding TLS logic to rabbitmq
- 0.1.8 Make helm test work with TLS
- 0.1.9 Use full image ref for docker official images
- 0.1.10 Set separate for HTTPS
- 0.1.11 Add TLS support for helm test
- 0.1.12 Added helm hook post-install and post-upgrade for rabbitmq wait cluster job
- 0.1.13 Add prestop action and version 3.8.x upgrade prep
- 0.1.14 Update readiness and liveness probes
- 0.1.15 Update htk requirements
- 0.1.16 Add force_boot command to rabbit start template
- 0.1.17 Updated naming for subchart compatibility
- 0.1.18 Revert naming for subchart compatibility
- 0.1.19 Enable taint toleration for Openstack services jobs
- 0.1.20 Bump Rabbitmq version to 3.9.0
- 0.1.21 Updated naming for subchart compatibility
- 0.1.22 Remove guest admin account
- 0.1.23 Fixed guest account removal
- 0.1.24 Added OCI registry authentication
- 0.1.25 Add hostPort support
- 0.1.26 Moved guest admin removal to init template
- 0.1.27 Replace node-role.kubernetes.io/master with control-plane
- 0.1.28 Add IPv6 environment support for rabbitmq
- 0.1.29 Add build-in prometheus plugin and disable external exporter
- 0.1.30 Add labels to rabbitmq service
- 0.1.31 Support management api metrics collection
- 0.1.32 Enable addition of default consumer prefetch count
- 0.1.33 Bump RabbitMQ image version to 3.13.0
- 0.1.34 Add 2024.1 overrides
- 0.1.35 Add configurable probes to rabbitmq container
- 0.1.36 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.37 Update rabbitmq readiness/liveness command
- 0.1.38 Do not use hardcoded username in rabbitmq chown container
- 0.1.39 Allow to bootstrap rabbitmq with initial config
- 0.1.40 Set password for guest user rabbitmq
- 0.1.41 Use short rabbitmq node name
- 0.1.42 Revert Use short rabbitmq node name
- 0.1.43 Add 2024.2 overrides
- 0.1.44 Allow to use default storage class
- 0.1.45 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
